## -*- coding: utf-8 -*-
## Copyright (C) 2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from cStringIO import StringIO
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.utils import getToolByName
from Products.LinguaFace import config
from Products.LinguaFace.LinguaFaceTool import LinguaFaceTool
from Products.ExternalMethod.ExternalMethod import manage_addExternalMethod
import string

def installSubSkin(context, skinFolder, outStream):
    """
        Install a subskin in portal_skins
    """
    skinsTool = getToolByName(context, 'portal_skins')
    for skin in skinsTool.getSkinSelections() :
        path = skinsTool.getSkinPath(skin)
        path = map(string.strip, string.split(path, ','))
        if not skinFolder in path:
            try:
                path.insert(path.index('custom') + 1, skinFolder)
            except ValueError:
                path.append(skinFolder)
            path = string.join(path, ', ')
            skinsTool.addSkinSelection(skin, path)
            outStream.write('Subskin successfully installed into %s.\n' % skin)
        else:
            outStream.write('*** Subskin was already installed into %s.\n' % skin)

def addTool(self) :
    # Check that the tool has not been added using its id
    if not hasattr(self, LinguaFaceTool.id) :
        addTool = self.manage_addProduct[config.PROJECTNAME].manage_addTool
        # Add the tool by its meta_type
        addTool(LinguaFaceTool.meta_type)

def installConfiglet(self, out) :
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        for conf in config.configlets:
            configTool.registerConfiglet(**conf)
            out.write('Added configlet %s\n' % conf['id'])

def uninstallConfiglet(self, out) :
    configTool = getToolByName(self, 'portal_controlpanel', None)
    if configTool:
        for conf in config.configlets:
            configTool.unregisterConfiglet(conf['id'])
            out.write('Removed configlet %s\n' % conf['id'])

def registerJavaScript(self, out):
    jsTool = getToolByName(self, 'portal_javascripts', None)
    if jsTool:
        jsTool.manage_addScript(
            "linguaface.js",
            cookable=True,
            enabled=True,
            inline=False
        )
        out.write("Javascript registered succesfully.\n")

def registerCSS(self, out):
    ctool = getToolByName(self, 'portal_css')
    ctool.registerStylesheet('linguaface.css', title='LinguaFace')
    print >> out, 'CSS installed'

def addCanonicalPathIndex(self, out):
    portal_catalog = getToolByName(self, 'portal_catalog')
    portal_catalog.addIndex('getCanonicalPath', 'ExtendedPathIndex')
    out.write("getCanonicalPath index added sucessfully\n")
    portal_catalog.addColumn('getCanonicalPath')
    out.write("getCanonicalPath metadata added sucessfully\n")
    brains = portal_catalog.searchResults()
    for brain in brains:
        ob = brain.getObject()
        ob.reindexObject(idxs=['getCanonicalPath'])
    out.write("portal_catalog rebuilt sucessfully\n")

def addExternalMethod(self, out):
    manage_addExternalMethod(self, id='assembleCopies',
                       title='assembleCopies',
                       module='LinguaFace.assembleCopies',
                       function='assembleCopies')
    out.write("The external method assembleCopies was added successfully\n")

def removeCanonicalPathIndex(self, out):
    portal_catalog = getToolByName(self, 'portal_catalog')
    portal_catalog.delIndex('getCanonicalPath')
    out.write("getCanonicalPath index deleted sucessfully\n")
    portal_catalog.delColumn('getCanonicalPath')
    out.write("getCanonicalPath metadata deleted sucessfully\n")
    out.write("portal_catalog rebuilt sucessfully\n")


def removeExternalMethod(self, out):
    self.manage_delObjects(['assembleCopies'])
    out.write("The external method assembleCopies was removed successfully\n")

def install(self) :
    outStream = StringIO()
    skinsTool = getToolByName(self, 'portal_skins')
    addDirectoryViews(skinsTool, 'skins', config.GLOBALS)
    installSubSkin(self, config.SKIN_NAME, outStream)
    addTool(self)
    installConfiglet(self, outStream)
    registerJavaScript(self, outStream)
    registerCSS(self, outStream)
    addCanonicalPathIndex(self, outStream)
    addExternalMethod(self, outStream)
    return outStream.getvalue()

def uninstall(self):
    outStream = StringIO()
    removeCanonicalPathIndex(self, outStream)
    removeExternalMethod(self, outStream)
    return outStream.getvalue()


